summaryrefslogtreecommitdiffstats
path: root/kicker
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:26:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:26:07 -0600
commit43d99cc2477266cb9072e179137f0e8485370b3d (patch)
tree0d4d47e5497a1a1465edf8263f57b72725577239 /kicker
parent6354e6b3babad3ed0f5e314735bbbc01d1988eb2 (diff)
downloadtdebase-43d99cc2477266cb9072e179137f0e8485370b3d.tar.gz
tdebase-43d99cc2477266cb9072e179137f0e8485370b3d.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'kicker')
-rw-r--r--kicker/applets/clock/datepicker.cpp2
-rw-r--r--kicker/applets/menu/menuapplet.cpp4
-rw-r--r--kicker/applets/minipager/pagerapplet.cpp86
-rw-r--r--kicker/applets/minipager/pagerapplet.h6
-rw-r--r--kicker/applets/minipager/pagerbutton.cpp18
-rw-r--r--kicker/applets/swallow/swallow.cpp4
-rw-r--r--kicker/applets/systemtray/systemtrayapplet.cpp16
-rw-r--r--kicker/applets/systemtray/systemtrayapplet.h2
-rw-r--r--kicker/extensions/dockbar/dockbarextension.cpp12
-rw-r--r--kicker/extensions/dockbar/dockbarextension.h2
-rw-r--r--kicker/extensions/dockbar/dockcontainer.cpp2
-rw-r--r--kicker/extensions/kasbar/ChangeLog4
-rw-r--r--kicker/extensions/kasbar/kasbarapp.cpp2
-rw-r--r--kicker/extensions/kasbar/kasclockitem.cpp2
-rw-r--r--kicker/extensions/kasbar/kasgroupitem.cpp2
-rw-r--r--kicker/extensions/kasbar/kasloaditem.cpp2
-rw-r--r--kicker/extensions/kasbar/kasstartupitem.cpp2
-rw-r--r--kicker/kicker/buttons/windowlistbutton.cpp2
-rw-r--r--kicker/kicker/core/container_applet.h2
-rw-r--r--kicker/kicker/core/container_extension.cpp8
-rw-r--r--kicker/kicker/core/extensionmanager.cpp8
-rw-r--r--kicker/kicker/core/kicker.cpp14
-rw-r--r--kicker/kicker/core/kicker.h4
-rw-r--r--kicker/kicker/core/showdesktop.cpp32
-rw-r--r--kicker/kicker/ui/itemview.cpp2
-rw-r--r--kicker/kicker/ui/k_mnu.cpp2
-rw-r--r--kicker/kicker/ui/k_new_mnu.cpp2
-rw-r--r--kicker/proxy/appletproxy.cpp2
-rw-r--r--kicker/taskbar/taskbarcontainer.cpp2
-rw-r--r--kicker/taskbar/taskcontainer.cpp2
-rw-r--r--kicker/taskmanager/taskmanager.cpp2
-rw-r--r--kicker/taskmanager/taskmanager.h2
32 files changed, 127 insertions, 127 deletions
diff --git a/kicker/applets/clock/datepicker.cpp b/kicker/applets/clock/datepicker.cpp
index 3f5d5b4ed..7823df539 100644
--- a/kicker/applets/clock/datepicker.cpp
+++ b/kicker/applets/clock/datepicker.cpp
@@ -27,7 +27,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdatepicker.h>
#include <kiconloader.h>
#include <klocale.h>
-#include <kwin.h>
+#include <twin.h>
#include <netwm.h>
DatePicker::DatePicker(TQWidget *parent, const TQDate& date, Prefs* _prefs)
diff --git a/kicker/applets/menu/menuapplet.cpp b/kicker/applets/menu/menuapplet.cpp
index f0c05d83c..f0a86946f 100644
--- a/kicker/applets/menu/menuapplet.cpp
+++ b/kicker/applets/menu/menuapplet.cpp
@@ -35,8 +35,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdebug.h>
#include <kglobal.h>
#include <klocale.h>
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
#include <netwm.h>
diff --git a/kicker/applets/minipager/pagerapplet.h b/kicker/applets/minipager/pagerapplet.h
index e72f44588..02f72198e 100644
--- a/kicker/applets/minipager/pagerapplet.h
+++ b/kicker/applets/minipager/pagerapplet.h
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqintdict.h>
#include <kpanelapplet.h>
-#include <kwin.h>
+#include <twin.h>
#include "pagerbutton.h"
#include "pagersettings.h"
@@ -58,7 +58,7 @@ public:
int heightForWidth(int width) const;
KWin::WindowInfo* info( WId win );
- KWinModule* kwin() { return m_kwin; }
+ KWinModule* twin() { return m_twin; }
KTextShadowEngine* shadowEngine();
void setActive( WId active ) { m_activeWindow = active; }
@@ -128,7 +128,7 @@ private:
int desktopLayoutY;
KSelectionOwner* m_desktopLayoutOwner;
- KWinModule *m_kwin;
+ KWinModule *m_twin;
KTextShadowEngine* m_shadowEngine;
TQPopupMenu *m_contextMenu;
diff --git a/kicker/applets/minipager/pagerbutton.cpp b/kicker/applets/minipager/pagerbutton.cpp
index d6047d407..e494d538d 100644
--- a/kicker/applets/minipager/pagerbutton.cpp
+++ b/kicker/applets/minipager/pagerbutton.cpp
@@ -33,7 +33,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <netwm.h>
#include <dcopclient.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <ksharedpixmap.h>
#include <kpixmapio.h>
#include <kpixmapeffect.h>
@@ -81,7 +81,7 @@ KMiniPagerButton::KMiniPagerButton(int desk, bool useViewPorts, const TQPoint& v
setBackgroundOrigin(AncestorOrigin);
installEventFilter(KickerTip::the());
- m_desktopName = m_pager->kwin()->desktopName(m_desktop);
+ m_desktopName = m_pager->twin()->desktopName(m_desktop);
connect(this, TQT_SIGNAL(clicked()), TQT_SLOT(slotClicked()));
connect(this, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotToggled(bool)));
@@ -108,7 +108,7 @@ TQRect KMiniPagerButton::mapGeometryToViewport(const KWin::WindowInfo& info) con
// ### fix vertically layouted viewports
TQRect _r(info.frameGeometry());
- TQPoint vx(m_pager->kwin()->currentViewport(m_pager->kwin()->currentDesktop()));
+ TQPoint vx(m_pager->twin()->currentViewport(m_pager->twin()->currentDesktop()));
_r.moveBy( - (m_desktop - vx.x()) * TQApplication::desktop()->width(),
0);
@@ -127,7 +127,7 @@ TQPoint KMiniPagerButton::mapPointToViewport(const TQPoint& _p) const
{
if (!m_useViewports) return _p;
- TQPoint vx(m_pager->kwin()->currentViewport(m_pager->kwin()->currentDesktop()));
+ TQPoint vx(m_pager->twin()->currentViewport(m_pager->twin()->currentDesktop()));
// ### fix vertically layouted viewports
TQPoint p(_p);
@@ -443,12 +443,12 @@ void KMiniPagerButton::drawButton(TQPainter *bp)
// window preview...
if (m_pager->desktopPreview())
{
- KWinModule* kwin = m_pager->kwin();
+ KWinModule* twin = m_pager->twin();
KWin::WindowInfo *info = 0;
int dw = TQApplication::desktop()->width();
int dh = TQApplication::desktop()->height();
- TQValueList<WId> windows = kwin->stackingOrder();
+ TQValueList<WId> windows = twin->stackingOrder();
TQValueList<WId>::const_iterator itEnd = windows.constEnd();
for (TQValueList<WId>::ConstIterator it = windows.constBegin(); it != itEnd; ++it)
{
@@ -460,7 +460,7 @@ void KMiniPagerButton::drawButton(TQPainter *bp)
r = TQRect(r.x() * width() / dw, 2 + r.y() * height() / dh,
r.width() * width() / dw, r.height() * height() / dh);
- if (kwin->activeWindow() == info->win())
+ if (twin->activeWindow() == info->win())
{
TQBrush brush = tqcolorGroup().brush(TQColorGroup::Highlight);
qDrawShadeRect(bp, r, tqcolorGroup(), false, 1, 0, &brush);
@@ -704,7 +704,7 @@ void KMiniPagerButton::dragLeaveEvent( TQDragLeaveEvent* e )
{
m_dragSwitchTimer.stop();
- if (m_pager->kwin()->currentDesktop() != m_desktop)
+ if (m_pager->twin()->currentDesktop() != m_desktop)
{
setDown(false);
}
@@ -750,7 +750,7 @@ bool KMiniPagerButton::eventFilter( TQObject *o, TQEvent * e)
if (o && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_lineEdit) &&
(e->type() == TQEvent::FocusOut || e->type() == TQEvent::Hide))
{
- m_pager->kwin()->setDesktopName( m_desktop, m_lineEdit->text() );
+ m_pager->twin()->setDesktopName( m_desktop, m_lineEdit->text() );
m_desktopName = m_lineEdit->text();
TQTimer::singleShot( 0, m_lineEdit, TQT_SLOT( deleteLater() ) );
m_lineEdit = 0;
diff --git a/kicker/applets/swallow/swallow.cpp b/kicker/applets/swallow/swallow.cpp
index 7112c706a..03be831e3 100644
--- a/kicker/applets/swallow/swallow.cpp
+++ b/kicker/applets/swallow/swallow.cpp
@@ -31,8 +31,8 @@
#include <kmessagebox.h>
#include <kprocess.h>
#include <kshell.h>
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
diff --git a/kicker/applets/systemtray/systemtrayapplet.cpp b/kicker/applets/systemtray/systemtrayapplet.cpp
index 619fdebcc..570db2f92 100644
--- a/kicker/applets/systemtray/systemtrayapplet.cpp
+++ b/kicker/applets/systemtray/systemtrayapplet.cpp
@@ -42,11 +42,11 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kdebug.h>
#include <kglobal.h>
#include <krun.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kdialogbase.h>
#include <kactionselector.h>
#include <kiconloader.h>
-#include <kwin.h>
+#include <twin.h>
#include "kickerSettings.h"
@@ -102,7 +102,7 @@ SystemTrayApplet::SystemTrayApplet(const TQString& configFile, Type type, int ac
setBackgroundOrigin(AncestorOrigin);
- kwin_module = new KWinModule(TQT_TQOBJECT(this));
+ twin_module = new KWinModule(TQT_TQOBJECT(this));
// kApplication notifies us of settings changes. added to support
// disabling of frame effect on mouse hover
@@ -121,7 +121,7 @@ void SystemTrayApplet::updateClockGeometry()
void SystemTrayApplet::initialize()
{
// register existing tray windows
- const TQValueList<WId> systemTrayWindows = kwin_module->systemTrayWindows();
+ const TQValueList<WId> systemTrayWindows = twin_module->systemTrayWindows();
bool existing = false;
for (TQValueList<WId>::ConstIterator it = systemTrayWindows.begin();
it != systemTrayWindows.end(); ++it )
@@ -139,9 +139,9 @@ void SystemTrayApplet::initialize()
}
// the KWinModule notifies us when tray windows are added or removed
- connect( kwin_module, TQT_SIGNAL( systemTrayWindowAdded(WId) ),
+ connect( twin_module, TQT_SIGNAL( systemTrayWindowAdded(WId) ),
this, TQT_SLOT( systemTrayWindowAdded(WId) ) );
- connect( kwin_module, TQT_SIGNAL( systemTrayWindowRemoved(WId) ),
+ connect( twin_module, TQT_SIGNAL( systemTrayWindowRemoved(WId) ),
this, TQT_SLOT( updateTrayWindows() ) );
TQCString screenstr;
@@ -711,7 +711,7 @@ void SystemTrayApplet::updateTrayWindows()
WId wid = (*emb)->embeddedWinId();
if ((wid == 0) ||
((*emb)->kdeTray() &&
- !kwin_module->systemTrayWindows().contains(wid)))
+ !twin_module->systemTrayWindows().contains(wid)))
{
(*emb)->deleteLater();
emb = m_shownWins.erase(emb);
@@ -728,7 +728,7 @@ void SystemTrayApplet::updateTrayWindows()
WId wid = (*emb)->embeddedWinId();
if ((wid == 0) ||
((*emb)->kdeTray() &&
- !kwin_module->systemTrayWindows().contains(wid)))
+ !twin_module->systemTrayWindows().contains(wid)))
{
(*emb)->deleteLater();
emb = m_hiddenWins.erase(emb);
diff --git a/kicker/applets/systemtray/systemtrayapplet.h b/kicker/applets/systemtray/systemtrayapplet.h
index 868941c13..92aab7268 100644
--- a/kicker/applets/systemtray/systemtrayapplet.h
+++ b/kicker/applets/systemtray/systemtrayapplet.h
@@ -104,7 +104,7 @@ private:
TrayEmbedList m_hiddenWins;
TQStringList m_hiddenIconList;
TQStringList m_sortOrderIconList;
- KWinModule *kwin_module;
+ KWinModule *twin_module;
Atom net_system_tray_selection;
Atom net_system_tray_opcode;
bool m_showFrame;
diff --git a/kicker/extensions/dockbar/dockbarextension.h b/kicker/extensions/dockbar/dockbarextension.h
index eada2583b..4a5dff41f 100644
--- a/kicker/extensions/dockbar/dockbarextension.h
+++ b/kicker/extensions/dockbar/dockbarextension.h
@@ -61,7 +61,7 @@ protected:
void mouseReleaseEvent(TQMouseEvent *);
void mouseMoveEvent(TQMouseEvent *);
private:
- KWinModule* kwin_module;
+ KWinModule* twin_module;
DockContainer::Vector containers;
// handle the dragging of applets
diff --git a/kicker/extensions/dockbar/dockcontainer.cpp b/kicker/extensions/dockbar/dockcontainer.cpp
index 1d281619a..f6ac6bd33 100644
--- a/kicker/extensions/dockbar/dockcontainer.cpp
+++ b/kicker/extensions/dockbar/dockcontainer.cpp
@@ -23,7 +23,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqwidget.h>
#include <tqtooltip.h>
-#include <kwin.h>
+#include <twin.h>
#include <tqvalidator.h>
#include <kinputdialog.h>
#include <klocale.h>
diff --git a/kicker/extensions/kasbar/ChangeLog b/kicker/extensions/kasbar/ChangeLog
index 09408fc4a..67b22fd8a 100644
--- a/kicker/extensions/kasbar/ChangeLog
+++ b/kicker/extensions/kasbar/ChangeLog
@@ -384,7 +384,7 @@
2004-06-26 Saturday 00:28 rich
- * - Fix test program for kwin changes.
+ * - Fix test program for twin changes.
2004-06-26 Saturday 00:10 rich
@@ -698,7 +698,7 @@
2001-11-29 Thursday 19:23 rich
- * Switch to taskmanager task popup menu instead of kwin (avoids
+ * Switch to taskmanager task popup menu instead of twin (avoids
some problems)
2001-11-25 Sunday 02:03 rich
diff --git a/kicker/extensions/kasbar/kasbarapp.cpp b/kicker/extensions/kasbar/kasbarapp.cpp
index 17cbfb967..8ceceaf37 100644
--- a/kicker/extensions/kasbar/kasbarapp.cpp
+++ b/kicker/extensions/kasbar/kasbarapp.cpp
@@ -56,7 +56,7 @@
#include <kconfig.h>
#include <kdebug.h>
#include <dcopclient.h>
-#include <kwin.h>
+#include <twin.h>
#include <kglobal.h>
#include <klocale.h>
diff --git a/kicker/extensions/kasbar/kasclockitem.cpp b/kicker/extensions/kasbar/kasclockitem.cpp
index 518245d4b..959734c22 100644
--- a/kicker/extensions/kasbar/kasclockitem.cpp
+++ b/kicker/extensions/kasbar/kasclockitem.cpp
@@ -7,7 +7,7 @@
#include <kdatepicker.h>
#include <kglobal.h>
-#include <kwin.h>
+#include <twin.h>
#include <kiconloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>
diff --git a/kicker/extensions/kasbar/kasgroupitem.cpp b/kicker/extensions/kasbar/kasgroupitem.cpp
index fe5f02ef6..31615acbf 100644
--- a/kicker/extensions/kasbar/kasgroupitem.cpp
+++ b/kicker/extensions/kasbar/kasgroupitem.cpp
@@ -58,7 +58,7 @@
#include <kdebug.h>
#include <kglobal.h>
-#include <kwin.h>
+#include <twin.h>
#include <kiconloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>
diff --git a/kicker/extensions/kasbar/kasloaditem.cpp b/kicker/extensions/kasbar/kasloaditem.cpp
index e36d2d18d..459bd6639 100644
--- a/kicker/extensions/kasbar/kasloaditem.cpp
+++ b/kicker/extensions/kasbar/kasloaditem.cpp
@@ -14,7 +14,7 @@
#include <kdebug.h>
#include <kglobal.h>
-#include <kwin.h>
+#include <twin.h>
#include <kiconloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>
diff --git a/kicker/extensions/kasbar/kasstartupitem.cpp b/kicker/extensions/kasbar/kasstartupitem.cpp
index 4d2ac3b00..41adc5249 100644
--- a/kicker/extensions/kasbar/kasstartupitem.cpp
+++ b/kicker/extensions/kasbar/kasstartupitem.cpp
@@ -58,7 +58,7 @@
#include <kdebug.h>
#include <kglobal.h>
-#include <kwin.h>
+#include <twin.h>
#include <kiconloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>
diff --git a/kicker/kicker/buttons/windowlistbutton.cpp b/kicker/kicker/buttons/windowlistbutton.cpp
index 0b413d880..789911167 100644
--- a/kicker/kicker/buttons/windowlistbutton.cpp
+++ b/kicker/kicker/buttons/windowlistbutton.cpp
@@ -23,7 +23,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqtooltip.h>
-#include <kwindowlistmenu.h>
+#include <twindowlistmenu.h>
#include <klocale.h>
#include "windowlistbutton.h"
diff --git a/kicker/kicker/core/container_applet.h b/kicker/kicker/core/container_applet.h
index 019e52c96..18ce050d5 100644
--- a/kicker/kicker/core/container_applet.h
+++ b/kicker/kicker/core/container_applet.h
@@ -26,7 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kpanelapplet.h>
#include <dcopobject.h>
-#include <kwin.h>
+#include <twin.h>
#include "appletinfo.h"
#include "container_base.h"
diff --git a/kicker/kicker/core/container_extension.cpp b/kicker/kicker/core/container_extension.cpp
index 5b30dbad5..51a9904d7 100644
--- a/kicker/kicker/core/container_extension.cpp
+++ b/kicker/kicker/core/container_extension.cpp
@@ -44,13 +44,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kglobal.h>
#include <kicker.h>
#include <kstandarddirs.h>
-#include <kwin.h>
+#include <twin.h>
#include <klocale.h>
#include <kglobalsettings.h>
#include <kapplication.h>
#include <netwm.h>
#include <fixx11h.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include "container_base.h"
#include "extensionmanager.h"
@@ -136,8 +136,8 @@ void ExtensionContainer::init()
KWin::setState(winId(), NET::Sticky);
KWin::setOnAllDesktops(winId(), true);
- connect(Kicker::the()->kwinModule(), TQT_SIGNAL(strutChanged()), this, TQT_SLOT(strutChanged()));
- connect(Kicker::the()->kwinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
+ connect(Kicker::the()->twinModule(), TQT_SIGNAL(strutChanged()), this, TQT_SLOT(strutChanged()));
+ connect(Kicker::the()->twinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
this, TQT_SLOT( currentDesktopChanged(int)));
setBackgroundOrigin(AncestorOrigin);
diff --git a/kicker/kicker/core/extensionmanager.cpp b/kicker/kicker/core/extensionmanager.cpp
index 03e039ee0..d3ec91e2c 100644
--- a/kicker/kicker/core/extensionmanager.cpp
+++ b/kicker/kicker/core/extensionmanager.cpp
@@ -35,7 +35,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kmenubar.h>
#include <kmessagebox.h>
#include <kstandarddirs.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <dcopref.h>
#include "container_extension.h"
@@ -625,7 +625,7 @@ TQRect ExtensionManager::workArea(int XineramaScreen, const ExtensionContainer*
{
if (!extension)
{
- return Kicker::the()->kwinModule()->workArea(XineramaScreen);
+ return Kicker::the()->twinModule()->workArea(XineramaScreen);
}
TQValueList<WId> list;
@@ -676,11 +676,11 @@ TQRect ExtensionManager::workArea(int XineramaScreen, const ExtensionContainer*
if ((XineramaScreen == XineramaAllScreens) || (kapp->desktop()->numScreens() < 2))
{
/* special value for all screens */
- workArea = Kicker::the()->kwinModule()->workArea(list);
+ workArea = Kicker::the()->twinModule()->workArea(list);
}
else
{
- workArea = Kicker::the()->kwinModule()->workArea(list, XineramaScreen)
+ workArea = Kicker::the()->twinModule()->workArea(list, XineramaScreen)
.intersect(TQApplication::desktop()->screenGeometry(XineramaScreen));
}
diff --git a/kicker/kicker/core/kicker.cpp b/kicker/kicker/core/kicker.cpp
index 7ba06c61c..f4d0edc40 100644
--- a/kicker/kicker/core/kicker.cpp
+++ b/kicker/kicker/core/kicker.cpp
@@ -42,8 +42,8 @@
#include <klocale.h>
#include <kmessagebox.h>
#include <kstandarddirs.h>
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
#include "extensionmanager.h"
#include "pluginmanager.h"
@@ -64,7 +64,7 @@ Kicker* Kicker::the() { return static_cast<Kicker*>(kapp); }
Kicker::Kicker()
: KUniqueApplication(),
keys(0),
- m_kwinModule(0),
+ m_twinModule(0),
m_configDialog(0),
m_canAddContainers(true)
{
@@ -379,14 +379,14 @@ void Kicker::clearQuickStartMenu()
MenuManager::the()->kmenu()->clearRecentMenuItems();
}
-KWinModule* Kicker::kwinModule()
+KWinModule* Kicker::twinModule()
{
- if (!m_kwinModule)
+ if (!m_twinModule)
{
- m_kwinModule = new KWinModule();
+ m_twinModule = new KWinModule();
}
- return m_kwinModule;
+ return m_twinModule;
}
TQRect Kicker::desktopIconsArea(int screen) const
diff --git a/kicker/kicker/core/kicker.h b/kicker/kicker/core/kicker.h
index 6bb071007..bc00e1915 100644
--- a/kicker/kicker/core/kicker.h
+++ b/kicker/kicker/core/kicker.h
@@ -69,7 +69,7 @@ k_dcop_signals:
public:
static Kicker* the();
KDirWatch* fileWatcher();
- KWinModule* kwinModule();
+ KWinModule* twinModule();
bool isImmutable() const;
bool isKioskImmutable() const;
@@ -122,7 +122,7 @@ private:
static void crashHandler(int signal);
KGlobalAccel* keys;
- KWinModule* m_kwinModule;
+ KWinModule* m_twinModule;
KCMultiDialog* m_configDialog;
bool m_canAddContainers;
TQPoint m_insertionPoint;
diff --git a/kicker/kicker/core/showdesktop.cpp b/kicker/kicker/core/showdesktop.cpp
index 7f75ba1b9..e41ddb549 100644
--- a/kicker/kicker/core/showdesktop.cpp
+++ b/kicker/kicker/core/showdesktop.cpp
@@ -26,8 +26,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "kicker.h"
#include "kickerSettings.h"
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
#include <netwm.h>
#include "showdesktop.h"
@@ -49,9 +49,9 @@ ShowDesktop::ShowDesktop()
m_wmSupport = i.isSupported( NET::WM2ShowingDesktop );
if( m_wmSupport )
{
- connect( Kicker::the()->kwinModule(), TQT_SIGNAL( showingDesktopChanged( bool )),
+ connect( Kicker::the()->twinModule(), TQT_SIGNAL( showingDesktopChanged( bool )),
TQT_SLOT( showingDesktopChanged( bool )));
- showingDesktopChanged( m_showingDesktop = Kicker::the()->kwinModule()->showingDesktop());
+ showingDesktopChanged( m_showingDesktop = Kicker::the()->twinModule()->showingDesktop());
}
}
@@ -74,9 +74,9 @@ void ShowDesktop::slotWindowAdded(WId w)
if ((windowType == NET::Normal || windowType == NET::Unknown) &&
inf.mappingState() == NET::Visible)
{
- KConfig kwincfg( "kwinrc", true ); // see in kwin
- kwincfg.setGroup( "Windows" );
- if( kwincfg.readBoolEntry( "ShowDesktopIsMinimizeAll", false ))
+ KConfig twincfg( "twinrc", true ); // see in twin
+ twincfg.setGroup( "Windows" );
+ if( twincfg.readBoolEntry( "ShowDesktopIsMinimizeAll", false ))
{
m_iconifiedList.clear();
m_showingDesktop = false;
@@ -130,10 +130,10 @@ void ShowDesktop::showDesktop( bool b )
if (b)
{
- m_activeWindow = Kicker::the()->kwinModule()->activeWindow();
+ m_activeWindow = Kicker::the()->twinModule()->activeWindow();
m_iconifiedList.clear();
- const TQValueList<WId> windows = Kicker::the()->kwinModule()->windows();
+ const TQValueList<WId> windows = Kicker::the()->twinModule()->windows();
for (TQValueList<WId>::ConstIterator it = windows.begin();
it != windows.end();
++it)
@@ -145,7 +145,7 @@ void ShowDesktop::showDesktop( bool b )
if (info.mappingState() == NET::Visible &&
(info.desktop() == NETWinInfo::OnAllDesktops ||
- info.desktop() == (int)Kicker::the()->kwinModule()->currentDesktop()))
+ info.desktop() == (int)Kicker::the()->twinModule()->currentDesktop()))
{
m_iconifiedList.append( w );
}
@@ -161,20 +161,20 @@ void ShowDesktop::showDesktop( bool b )
}
// on desktop changes or when a window is deiconified, we abort the show desktop mode
- connect(Kicker::the()->kwinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
+ connect(Kicker::the()->twinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
TQT_SLOT(slotCurrentDesktopChanged(int)));
- connect(Kicker::the()->kwinModule(), TQT_SIGNAL(windowChanged(WId,unsigned int)),
+ connect(Kicker::the()->twinModule(), TQT_SIGNAL(windowChanged(WId,unsigned int)),
TQT_SLOT(slotWindowChanged(WId,unsigned int)));
- connect(Kicker::the()->kwinModule(), TQT_SIGNAL(windowAdded(WId)),
+ connect(Kicker::the()->twinModule(), TQT_SIGNAL(windowAdded(WId)),
TQT_SLOT(slotWindowAdded(WId)));
}
else
{
- disconnect(Kicker::the()->kwinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
+ disconnect(Kicker::the()->twinModule(), TQT_SIGNAL(currentDesktopChanged(int)),
this, TQT_SLOT(slotCurrentDesktopChanged(int)));
- disconnect(Kicker::the()->kwinModule(), TQT_SIGNAL(windowChanged(WId,unsigned int)),
+ disconnect(Kicker::the()->twinModule(), TQT_SIGNAL(windowChanged(WId,unsigned int)),
this, TQT_SLOT(slotWindowChanged(WId,unsigned int)));
- disconnect(Kicker::the()->kwinModule(), TQT_SIGNAL(windowAdded(WId)),
+ disconnect(Kicker::the()->twinModule(), TQT_SIGNAL(windowAdded(WId)),
this, TQT_SLOT(slotWindowAdded(WId)));
for (TQValueVector<WId>::ConstIterator it = m_iconifiedList.begin();
diff --git a/kicker/kicker/ui/itemview.cpp b/kicker/kicker/ui/itemview.cpp
index 36a7bef7d..f9ab06006 100644
--- a/kicker/kicker/ui/itemview.cpp
+++ b/kicker/kicker/ui/itemview.cpp
@@ -59,7 +59,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kmessagebox.h>
#include <kstandarddirs.h>
#include <kcombobox.h>
-#include <kwin.h>
+#include <twin.h>
#include <kdebug.h>
#include <kmimetype.h>
#include <kmultipledrag.h>
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index d6d130a02..6953143c9 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -50,7 +50,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kmessagebox.h>
#include <kstandarddirs.h>
#include <ktoolbarbutton.h>
-#include <kwin.h>
+#include <twin.h>
#include "client_mnu.h"
#include "container_base.h"
diff --git a/kicker/kicker/ui/k_new_mnu.cpp b/kicker/kicker/ui/k_new_mnu.cpp
index 1a87b163d..e27f47d88 100644
--- a/kicker/kicker/ui/k_new_mnu.cpp
+++ b/kicker/kicker/ui/k_new_mnu.cpp
@@ -58,7 +58,7 @@
#include <kmessagebox.h>
#include <kstandarddirs.h>
#include <kcombobox.h>
-#include <kwin.h>
+#include <twin.h>
#include <kdebug.h>
#include <kuser.h>
#include <kurllabel.h>
diff --git a/kicker/proxy/appletproxy.cpp b/kicker/proxy/appletproxy.cpp
index 7b8243777..0f18914f3 100644
--- a/kicker/proxy/appletproxy.cpp
+++ b/kicker/proxy/appletproxy.cpp
@@ -40,7 +40,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kaboutdata.h>
#include <tqfileinfo.h>
#include <dcopclient.h>
-#include <kwin.h>
+#include <twin.h>
#include "appletinfo.h"
diff --git a/kicker/taskbar/taskbarcontainer.cpp b/kicker/taskbar/taskbarcontainer.cpp
index bfd1a40bf..404c27e24 100644
--- a/kicker/taskbar/taskbarcontainer.cpp
+++ b/kicker/taskbar/taskbarcontainer.cpp
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kapplication.h>
#include <kdebug.h>
#include <kiconloader.h>
-#include <kwindowlistmenu.h>
+#include <twindowlistmenu.h>
#include <X11/X.h>
#include <X11/Xlib.h>
diff --git a/kicker/taskbar/taskcontainer.cpp b/kicker/taskbar/taskcontainer.cpp
index 037f65b68..7c850e853 100644
--- a/kicker/taskbar/taskcontainer.cpp
+++ b/kicker/taskbar/taskcontainer.cpp
@@ -1140,7 +1140,7 @@ void TaskContainer::popupMenu(int action)
}
else if (action == TaskBarSettings::ShowOperationsMenu)
{
- if (!kapp->authorizeKAction("kwin_rmb"))
+ if (!kapp->authorizeKAction("twin_rmb"))
{
return;
}
diff --git a/kicker/taskmanager/taskmanager.cpp b/kicker/taskmanager/taskmanager.cpp
index 3b2316e4d..f6cff4248 100644
--- a/kicker/taskmanager/taskmanager.cpp
+++ b/kicker/taskmanager/taskmanager.cpp
@@ -33,7 +33,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <klocale.h>
// #include <kpixmapio.h>
#include <kstaticdeleter.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kxerrorhandler.h>
#include <netwm.h>
diff --git a/kicker/taskmanager/taskmanager.h b/kicker/taskmanager/taskmanager.h
index ddd5327d2..febb923e2 100644
--- a/kicker/taskmanager/taskmanager.h
+++ b/kicker/taskmanager/taskmanager.h
@@ -39,7 +39,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <ksharedptr.h>
#include <kstartupinfo.h>
-#include <kwin.h>
+#include <twin.h>
#include <config.h>
diff --git a/kicker/applets/minipager/pagerapplet.cpp b/kicker/applets/minipager/pagerapplet.cpp
index 6975af0c0..a684aa6f8 100644
--- a/kicker/applets/minipager/pagerapplet.cpp
+++ b/kicker/applets/minipager/pagerapplet.cpp
@@ -30,8 +30,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <dcopref.h>
#include <kglobalsettings.h>
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
#include <kapplication.h>
#include <kglobal.h>
#include <klocale.h>
@@ -114,11 +114,11 @@ KMiniPager::KMiniPager(const TQString& configFile, Type type, int actions,
setFont( KGlobalSettings::taskbarFont() );
- m_kwin = new KWinModule(TQT_TQOBJECT(this));
- m_activeWindow = m_kwin->activeWindow();
- m_curDesk = m_kwin->currentDesktop();
+ m_twin = new KWinModule(TQT_TQOBJECT(this));
+ m_activeWindow = m_twin->activeWindow();
+ m_curDesk = m_twin->currentDesktop();
- if (m_curDesk == 0) // kwin not yet launched
+ if (m_curDesk == 0) // twin not yet launched
{
m_curDesk = 1;
}
@@ -127,20 +127,20 @@ KMiniPager::KMiniPager(const TQString& configFile, Type type, int actions,
desktopLayoutX = -1;
desktopLayoutY = -1;
- TQSize s(m_kwin->numberOfViewports(m_kwin->currentDesktop()));
+ TQSize s(m_twin->numberOfViewports(m_twin->currentDesktop()));
m_useViewports = s.width() * s.height() > 1;
drawButtons();
- connect( m_kwin, TQT_SIGNAL( currentDesktopChanged(int)), TQT_SLOT( slotSetDesktop(int) ) );
- connect( m_kwin, TQT_SIGNAL( currentDesktopViewportChanged(int, const TQPoint&)), TQT_SLOT(slotSetDesktopViewport(int, const TQPoint&)));
- connect( m_kwin, TQT_SIGNAL( numberOfDesktopsChanged(int)), TQT_SLOT( slotSetDesktopCount(int) ) );
- connect( m_kwin, TQT_SIGNAL( desktopGeometryChanged(int)), TQT_SLOT( slotRefreshViewportCount(int) ) );
- connect( m_kwin, TQT_SIGNAL( activeWindowChanged(WId)), TQT_SLOT( slotActiveWindowChanged(WId) ) );
- connect( m_kwin, TQT_SIGNAL( windowAdded(WId) ), this, TQT_SLOT( slotWindowAdded(WId) ) );
- connect( m_kwin, TQT_SIGNAL( windowRemoved(WId) ), this, TQT_SLOT( slotWindowRemoved(WId) ) );
- connect( m_kwin, TQT_SIGNAL( windowChanged(WId,unsigned int) ), this, TQT_SLOT( slotWindowChanged(WId,unsigned int) ) );
- connect( m_kwin, TQT_SIGNAL( desktopNamesChanged() ), this, TQT_SLOT( slotDesktopNamesChanged() ) );
+ connect( m_twin, TQT_SIGNAL( currentDesktopChanged(int)), TQT_SLOT( slotSetDesktop(int) ) );
+ connect( m_twin, TQT_SIGNAL( currentDesktopViewportChanged(int, const TQPoint&)), TQT_SLOT(slotSetDesktopViewport(int, const TQPoint&)));
+ connect( m_twin, TQT_SIGNAL( numberOfDesktopsChanged(int)), TQT_SLOT( slotSetDesktopCount(int) ) );
+ connect( m_twin, TQT_SIGNAL( desktopGeometryChanged(int)), TQT_SLOT( slotRefreshViewportCount(int) ) );
+ connect( m_twin, TQT_SIGNAL( activeWindowChanged(WId)), TQT_SLOT( slotActiveWindowChanged(WId) ) );
+ connect( m_twin, TQT_SIGNAL( windowAdded(WId) ), this, TQT_SLOT( slotWindowAdded(WId) ) );
+ connect( m_twin, TQT_SIGNAL( windowRemoved(WId) ), this, TQT_SLOT( slotWindowRemoved(WId) ) );
+ connect( m_twin, TQT_SIGNAL( windowChanged(WId,unsigned int) ), this, TQT_SLOT( slotWindowChanged(WId,unsigned int) ) );
+ connect( m_twin, TQT_SIGNAL( desktopNamesChanged() ), this, TQT_SLOT( slotDesktopNamesChanged() ) );
connect( kapp, TQT_SIGNAL(backgroundChanged(int)), TQT_SLOT(slotBackgroundChanged(int)) );
if (kapp->authorizeKAction("kicker_rmb") && kapp->authorizeControlModule("kde-kcmtaskbar.desktop"))
@@ -152,8 +152,8 @@ KMiniPager::KMiniPager(const TQString& configFile, Type type, int actions,
}
TQValueList<WId>::ConstIterator it;
- TQValueList<WId>::ConstIterator itEnd = m_kwin->windows().end();
- for ( it = m_kwin->windows().begin(); it != itEnd; ++it)
+ TQValueList<WId>::ConstIterator itEnd = m_twin->windows().end();
+ for ( it = m_twin->windows().begin(); it != itEnd; ++it)
{
slotWindowAdded( (*it) );
}
@@ -172,7 +172,7 @@ KMiniPager::~KMiniPager()
void KMiniPager::slotBackgroundChanged(int desk)
{
- unsigned numDesktops = m_kwin->numberOfDesktops();
+ unsigned numDesktops = m_twin->numberOfDesktops();
if (numDesktops != m_desktops.count())
{
slotSetDesktopCount(numDesktops);
@@ -189,9 +189,9 @@ void KMiniPager::slotBackgroundChanged(int desk)
void KMiniPager::slotSetDesktop(int desktop)
{
- if (m_kwin->numberOfDesktops() > static_cast<int>(m_desktops.count()))
+ if (m_twin->numberOfDesktops() > static_cast<int>(m_desktops.count()))
{
- slotSetDesktopCount( m_kwin->numberOfDesktops() );
+ slotSetDesktopCount( m_twin->numberOfDesktops() );
}
if (!m_useViewports && (desktop != KWin::currentDesktop()))
@@ -200,8 +200,8 @@ void KMiniPager::slotSetDesktop(int desktop)
// holds down the key combo to switch desktops, lets the
// mouse go but keeps the key combo held. the desktop will switch
// back to the desktop associated with the key combo and then it
// becomes a race condition between kwin's signal and the button's
// signal. usually kwin wins.
return;
}
@@ -222,21 +222,21 @@ void KMiniPager::slotSetDesktopViewport(int desktop, const TQPoint& viewport)
{
// ###
Q_UNUSED(desktop);
- TQSize s(m_kwin->numberOfViewports(m_kwin->currentDesktop()));
+ TQSize s(m_twin->numberOfViewports(m_twin->currentDesktop()));
slotSetDesktop((viewport.y()-1) * s.width() + viewport.x() );
}
void KMiniPager::slotButtonSelected( int desk )
{
- if (m_kwin->numberOfViewports(m_kwin->currentDesktop()).width() *
- m_kwin->numberOfViewports(m_kwin->currentDesktop()).height() > 1)
+ if (m_twin->numberOfViewports(m_twin->currentDesktop()).width() *
+ m_twin->numberOfViewports(m_twin->currentDesktop()).height() > 1)
{
TQPoint p;
p.setX( (desk-1) * TQApplication::desktop()->width());
p.setY( 0 );
- KWin::setCurrentDesktopViewport(m_kwin->currentDesktop(), p);
+ KWin::setCurrentDesktopViewport(m_twin->currentDesktop(), p);
}
else
KWin::setCurrentDesktop( desk );
@@ -251,8 +251,8 @@ int KMiniPager::widthForHeight(int h) const
return width();
}
- int deskNum = m_kwin->numberOfDesktops() * m_kwin->numberOfViewports(0).width()
- * m_kwin->numberOfViewports(0).height();
+ int deskNum = m_twin->numberOfDesktops() * m_twin->numberOfViewports(0).width()
+ * m_twin->numberOfViewports(0).height();
int rowNum = m_settings->numberOfRows();
if (rowNum == 0)
@@ -286,7 +286,7 @@ int KMiniPager::widthForHeight(int h) const
TQFontMetrics fm = fontMetrics();
for (int i = 1; i <= deskNum; i++)
{
- int sw = fm.width( m_kwin->desktopName( i ) ) + 8;
+ int sw = fm.width( m_twin->desktopName( i ) ) + 8;
if (sw > bw)
{
bw = sw;
@@ -307,8 +307,8 @@ int KMiniPager::heightForWidth(int w) const
return height();
}
- int deskNum = m_kwin->numberOfDesktops() * m_kwin->numberOfViewports(0).width()
- * m_kwin->numberOfViewports(0).height();
+ int deskNum = m_twin->numberOfDesktops() * m_twin->numberOfViewports(0).width()
+ * m_twin->numberOfViewports(0).height();
int rowNum = m_settings->numberOfRows(); // actually these are columns now... oh well.
if (rowNum == 0)
{
@@ -442,8 +442,8 @@ void KMiniPager::wheelEvent( TQWheelEvent* e )
{
int newDesk;
int desktops = KWin::numberOfDesktops();
- if (m_kwin->numberOfViewports(0).width() * m_kwin->numberOfViewports(0).height() > 1 )
- desktops = m_kwin->numberOfViewports(0).width() * m_kwin->numberOfViewports(0).height();
+ if (m_twin->numberOfViewports(0).width() * m_twin->numberOfViewports(0).height() > 1 )
+ desktops = m_twin->numberOfViewports(0).width() * m_twin->numberOfViewports(0).height();
if (e->delta() < 0)
{
newDesk = m_curDesk % desktops + 1;
@@ -458,17 +458,17 @@ void KMiniPager::wheelEvent( TQWheelEvent* e )
void KMiniPager::drawButtons()
{
- int deskNum = m_kwin->numberOfDesktops();
+ int deskNum = m_twin->numberOfDesktops();
KMiniPagerButton *desk;
int count = 1;
int i = 1;
do
{
- TQSize viewportNum = m_kwin->numberOfViewports(i);
+ TQSize viewportNum = m_twin->numberOfViewports(i);
for (int j = 1; j <= viewportNum.width() * viewportNum.height(); ++j)
{
- TQSize s(m_kwin->numberOfViewports(m_kwin->currentDesktop()));
+ TQSize s(m_twin->numberOfViewports(m_twin->currentDesktop()));
TQPoint viewport( (j-1) % s.width(), (j-1) / s.width());
desk = new KMiniPagerButton( count, m_useViewports, viewport, this );
if ( m_settings->labelType() != PagerSettings::EnumLabelType::LabelName )
@@ -493,7 +493,7 @@ void KMiniPager::drawButtons()
void KMiniPager::slotSetDesktopCount( int )
{
- TQSize s(m_kwin->numberOfViewports(m_kwin->currentDesktop()));
+ TQSize s(m_twin->numberOfViewports(m_twin->currentDesktop()));
m_useViewports = s.width() * s.height() > 1;
TQValueList<KMiniPagerButton*>::ConstIterator it;
@@ -506,7 +506,7 @@ void KMiniPager::slotSetDesktopCount( int )
drawButtons();
- m_curDesk = m_kwin->currentDesktop();
+ m_curDesk = m_twin->currentDesktop();
if ( m_curDesk == 0 )
{
m_curDesk = 1;
@@ -518,7 +518,7 @@ void KMiniPager::slotSetDesktopCount( int )
void KMiniPager::slotRefreshViewportCount( int )
{
- TQSize s(m_kwin->numberOfViewports(m_kwin->currentDesktop()));
+ TQSize s(m_twin->numberOfViewports(m_twin->currentDesktop()));
m_useViewports = s.width() * s.height() > 1;
TQValueList<KMiniPagerButton*>::ConstIterator it;
@@ -531,7 +531,7 @@ void KMiniPager::slotRefreshViewportCount( int )
drawButtons();
- m_curDesk = m_kwin->currentDesktop();
+ m_curDesk = m_twin->currentDesktop();
if ( m_curDesk == 0 )
{
m_curDesk = 1;
@@ -709,7 +709,7 @@ void KMiniPager::aboutToShowContextMenu()
m_contextMenu->insertSeparator();
m_contextMenu->insertItem(i18n("&Rename Desktop \"%1\"")
- .arg(kwin()->desktopName(m_rmbDesk)), RenameDesktop);
+ .arg(twin()->desktopName(m_rmbDesk)), RenameDesktop);
m_contextMenu->insertSeparator();
KPopupMenu* showMenu = new KPopupMenu(m_contextMenu);
@@ -863,7 +863,7 @@ void KMiniPager::slotDesktopNamesChanged()
for (int i = 1; it != itEnd; ++it, ++i)
{
- TQString name = m_kwin->desktopName(i);
+ TQString name = m_twin->desktopName(i);
(*it)->setDesktopName(name);
(*it)->tqrepaint();
TQToolTip::remove((*it));
@@ -200,8 +200,8 @@ void KMiniPager::slotSetDesktop(int desktop)
// mouse go but keeps the key combo held. the desktop will switch
// back to the desktop associated with the key combo and then it
- // becomes a race condition between kwin's signal and the button's
- // signal. usually kwin wins.
+ // becomes a race condition between twin's signal and the button's
+ // signal. usually twin wins.
return;
}
diff --git a/kicker/extensions/dockbar/dockbarextension.cpp b/kicker/extensions/dockbar/dockbarextension.cpp
index aee6a728c..da20a2a61 100644
--- a/kicker/extensions/dockbar/dockbarextension.cpp
+++ b/kicker/extensions/dockbar/dockbarextension.cpp
@@ -23,12 +23,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#undef Bool // For enable-final
#include <klocale.h>
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kdebug.h>
#include <kconfig.h>
#include <kprocess.h>
#include <kshell.h>
-#include <kwin.h>
+#include <twin.h>
#include <kstandarddirs.h>
#include <kmessagebox.h>
#include <kapplication.h>
@@ -57,8 +57,8 @@ DockBarExtension::DockBarExtension(const TQString& configFile, Type type,
: KPanelExtension(configFile, type, actions, parent, name)
{
dragging_container = 0;
- kwin_module = new KWinModule(TQT_TQOBJECT(this));
- connect( kwin_module, TQT_SIGNAL( windowAdded(WId) ), TQT_SLOT( windowAdded(WId) ) );
+ twin_module = new KWinModule(TQT_TQOBJECT(this));
+ connect( twin_module, TQT_SIGNAL( windowAdded(WId) ), TQT_SLOT( windowAdded(WId) ) );
setMinimumSize(DockContainer::sz(), DockContainer::sz());
tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
loadContainerConfig();
@@ -154,8 +154,8 @@ void DockBarExtension::windowAdded(WId win)
kdDebug() << "Could not read XClassHint of window " << win << endl;
return;
}
- /* withdrawing the window prevents kwin from managing the window,
- which causes the double-launch bug (one instance from the kwin
+ /* withdrawing the window prevents twin from managing the window,
+ which causes the double-launch bug (one instance from the twin
session, and one from the dockbar) bug when kde is restarted */
if (resIconwin != win) {
XWithdrawWindow( qt_xdisplay(), win, qt_xscreen() );